--- client/tilespec.c.orig	2025-03-31 20:08:27.039106703 +0200
+++ client/tilespec.c	2025-03-31 20:12:24.440681834 +0200
@@ -3836,10 +3836,11 @@
     fc_assert(FALSE);
   }
 
   /* Corner road graphics are used by ESTYLE_ROAD_ALL_SEPARATE and
    * ESTYLE_ROAD_PARITY_COMBINED. */
   if (extrastyle == ESTYLE_ROAD_ALL_SEPARATE
-      || extrastyle == ESTYLE_ROAD_PARITY_COMBINED) {
+      || extrastyle == ESTYLE_ROAD_PARITY_COMBINED
+      || extrastyle == ESTYLE_ROAD_ALL_COMBINED) {
     for (i = 0; i < t->num_valid_tileset_dirs; i++) {
       enum direction8 dir = t->valid_tileset_dirs[i];
 
@@ -3850,6 +3851,7 @@
                     "%s_c_%s", pextra->graphic_str, dtn);
 
         SET_SPRITE_OPT(extras[id].u.road.corner[dir], full_tag_name);
+        printf("full_tag_name is %s\n",full_tag_name);
       }
     }
   }
@@ -3836,10 +3836,11 @@
   }
 
-  /* Corner road graphics are used by ESTYLE_ROAD_ALL_SEPARATE and
-   * ESTYLE_ROAD_PARITY_COMBINED. */
+  /* Corner road graphics are used by ESTYLE_ROAD_ALL_SEPARATE,
+   * ESTYLE_ROAD_PARITY_COMBINED  and ESTYLE_ROAD_ALL_COMBINED. */
   if (extrastyle == ESTYLE_ROAD_ALL_SEPARATE
